#
# spec file for package quimup
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2016 Packman team: http://packman.links2linux.org/
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _mainv  2.1.1
Name:           quimup
Version:        2.1.1
Release:        1.2
Summary:        A client for the music player daemon (MPD)
# was http://www.coonsden.com
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://quimup.sourceforge.io
Source0:        https://sourceforge.net/projects/quimup/files/Quimup%20%{_mainv}/Quimup-%{version}.source.tar.gz
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6Gui)
BuildRequires:  pkgconfig(Qt6Network)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(libmpdclient)
Requires:       mpd

%description
QUIMUP is a client for the music player daemon (MPD) written in C++ and QT3.

The program can be used with most Linux desktops (KDE, GNOME, XFCE).
The interface offers controlling MPD's many features.
The focus is on mouse handling: playlist management is done entirely by drag-&-drop;
playback functions are directly accessible from the system tray.

%prep
%autosetup -p1 -n Quimup-%{version}.source

%build
%qmake6
%qmake6_build

%install
install -D -m 0755 %{name} %{buildroot}/%{_bindir}/%{name}
install -D -m 0644 RPM_DEB_build/share/applications/Quimup.desktop \
  %{buildroot}/%{_datadir}/applications/%{name}.desktop
cp -r RPM_DEB_build/share/icons %{buildroot}/%{_datadir}
install -D -m 0644 RPM_DEB_build/share/man/man1/quimup.1 \
  %{buildroot}/%{_mandir}/man1/%{name}.1

%files
%doc changelog description faq readme
%license COPYING
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Wed Jan  1 2025 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.1.1
  * Added: Option to set the interval to poll MPD.
* Mon Jun  3 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.1.0
  Added features:
  * Album art size can be set (requires restart).
  * User actions to run scripts on files or directories.
  Fixed bugs:
  * Problems rendering odd- and under-sized album art.
  * Some menu items were disabled when they shouldn't be.
  * Streams had generic names and titles in the playlist.
  * Stream fetcher dit not handle https correctly.
  * Connect thread not closed before closing quimup.
  Other:
  * Only settings in active tab are applied/saved now.
  * If a song does not exist it is removed from the list.
  * Player has a bit more space for album info.
  * Smoother mini-maxi mode transition.
  * Items in the Settings window were reorganized.
* Fri Feb  9 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.0.1
  * Fixed: Albun art with W not equal to H caused problems.
* Mon Feb  5 2024 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.0.0
  * MIGRATED TO QT6
  Added features:
  * Wayland compatibility
  * Get album art directly from MPD, also remotely.
  * Large album comments are now mouse-scrollable.
  * Auto-reconnecting can be turned off.
  * MPD's command timeout can be set.
  * IPv6 for remote connections.
  * Parameter -e for more detailed cout.
  * Option 'Bold' and 'Italic' for various labels.
  * Icons and colors suited for a dark theme.
  * Option to apply colors to the progress bar.
  * Double-click on albumart opens it in image viewer.
  * Set default album/stream art from local file.
  * "Titles" mode for the library.
  * "Album" column to titles in library.
  * Connect tab shows if MPD is a user/system service.
  Fixed bugs:
  * A failing connection could freeze the program.
  * Searched titles were sorted by artist.
  * Connection crashed on 'mpd --kill' by the user.
  * Errors rendering artist-title when scrolling.
  * Artist-title scroll did not speed up on mouse-over.
  * Vertical alingment of scrolling artist-title.
  * Changing font size did not (de)activate scrolling.
  * Scrolling font waaay too big on Fedora.
  * Inconsistent handling of missing tag info.
  * Streams starting with https were refused.
  * Failing start/quit commands (like 'mpd --kill').
  * Window icon was always a generic 'W' in Wayland.
  * Systray's tooltip-text showed formatting code.
  * Window did not open to foreground from system tray.
  * Systray > Quit failed after close [x] from window.
  * Remotely starting external tracks (2xclick) failed.
  * Searching for local album art in the wrong order.
  * Files 'open with' command was rather ramshackle.
  * QtPainter error 'engine == 0' (error on cout).
  * Stream timing-out triggered reconnecting to MPD.
  * Media keys did not (all) work in the browser.
  * Erractic auto-column-width in library and playlist.
  * Palylist # column was too narrow for large numbers.
  * MPD could be found running when it was not.
  * Trying to connect locally when MPD is not running.
  * Starting MPD without checking if it is installed.
  * Not quitting MPD locally when connected remotely.
  * Autodetect ignored ~/.config/mpd/mpd.conf.
  * Context menus disappeared when not connected.
  * Not checking if external apps are installed.
  Other:
  * Auto-detect now prioritizes 'bind-to-address'es.
  * Auto-detect now runs only once, on startup.
  * Removed taglib (MPD gets embedded album art now).
  * Settings are now in ~/.config/quimup/quimup.conf.
  * All bitmaps are svg (scalable vector graphics) now.
  * Removes option to disable albumart..
  * Several minor text and tooltip tweaks.
  * Replaced obsolete email address in various places.
  * Updated 'README' and 'FAQ.txt' files.
  * Updated QtSingleApplication code from qt-solutions.
- Dropped quimup.desktop
- Added manpage
* Wed Dec 19 2018 aloisio@gmx.com
- Update to version 1.4.4
  * Fixed: Wrong time-stamp for some (single track) albums.
  * Fixed: Using the systray Quimup always started minimized.
  * Fixed: Player was not the active window after startup.
  * Fixed: Files dropped on playlist are inserted at position.
  * Fixed: Crash with deleted/moved external playlist items.
  * Fixed: Compilation error on Mageia (thanks David Geiger).
  * Fixed: libpng warning: iCCP: known incorrect sRGB profile.
  * Coded: Fixed many new c++ compiler warnings (not errors).
  * Coded: Added Taglib version check in qm_player (openSuse).
  * Other: Autoconfig searches more places for mpd.conf
  * Other: Settings window is now resizable (as it should be).
  * Other: Some changes in 'about' text and 'Settings' layout.
- Dropped quimup-gcc47.patch and quimup.patch (no longer
  necessary)
* Tue Jan  2 2018 jengelh@inai.de
- Trim marketing from description.
* Sat Dec 30 2017 aloisio@gmx.com
- Update to version 1.4.3:
  * Fixed: Possible crash when connection to MPD was lost.
  * Fixed: Settings window could be too small for comfort.
  * Fixed: Column widths not set in Library and Playlist view.
  * Fixed: Obsolete email address in 'about'.
  * Added: Option to start player minimized.
  * Other: Minor cosmetic changes.
- Refreshed quimup.patch
- Spec cleanup
* Wed Feb  8 2017 olaf@aepfle.de
- Fix crash in error_check() with quimup.patch
* Sun May 15 2016 dap.darkness@gmail.com
- Update to version 1.4.1:
  (note that 1.4.2 introduces build time issue against taglib)
  * Fixed: On startup player could show 2 close buttons.
  * Fixed: Folder browser did not list .m3u playlists
  * Coded: Added #include <QDataStream> to qtlocalpeer.h
  * Other: Minor changes in dialog text and command-line output.
  * Added: Use flac-type embedded cover art from ogg file.
- Removed quimup-1.4.0_qt5-5.5.patch.
* Mon Oct  5 2015 avvissu@yandex.ru
- Fix build on openSUSE > 13.2: quimup-1.4.0_qt5-5.5.patch
* Tue Mar 24 2015 aloisio@gmx.com
- update to version 1.4.0
  * Coded: Migrated the code to QT5
  * Fixed: After changing colors wrong album-art could be shown.
  * Added: Use embedded cover art from asf and ape-tagged mp3.
- spec cleanup
* Tue Jul  8 2014 dap.darkness@gmail.com
- new upstream version <1.3.2>
  * Fixed: Provided password was not used unconditionally.
  * Fixed: Playlist not updated when a dropped item was rejected.
  * Fixed: Settings were not saved upon system shutdown/logout.
  * Fixed: Could not find translation(s) in default location.
  * Fixed: Music dir was not always found automatically.
  * Added: Use embedded cover art (mp3 ogg mpc mp4 flac wv ape).
  * Added: Player and Browser now respond to 'media keys'.
  * Added: Support for *.cue playlist files in folder view.
  * Added: 'Reset status' to playlist context menu.
  * Added: '-l none' to cmd parameters to force internal locale.
  * Added: More extensions are accepted for D&D operations.
  * Other: Some cosmetic tweaks, as usual.
- added copyright&license header.
- removed clean section.
* Sat Dec 14 2013 dap.darkness@gmail.com
- new upstream version <1.3.1>
  * Added: Support for the 'Disc Number' tag.
  * Added: Stream loader can handle compound urls better.
  * Added: Manually override MPD's (remote) music dir.
  * Fixed: Crash upon calling mpd_return_pair (Archlinux).
  * Fixed: Player changed position after hide-show toggle.
  * Fixed: Allow more time to connect to MPD at start-up.
  * Fixed: Possible wrong sorting order of dragged items.
  * Coded: Project 'includes' libmpdclient using pkg-config.
* Sat Jan 12 2013 dap.darkness@gmail.com
- new upstream version <1.3.0>
  * Added: "Drag & drop" from file manager to quimup.
  * Added: "Open with" from file manager (%%U or %%F).
  * Added: Single-instance-mode (by default).
  * Added: Localization support (no translations yet).
  * Added: Command line parameters (try "quimup -help").
  * Added: Rescan tags for any selection (library menu).
  * Added: Folder search in the browser.
  * Added: Check if mpd is running when quimup starts up.
  * Added: Option to apply colors to the album info widget.
  * Added: Music directory is requested from MPD (0.17+).
  * Added: Playlist scrolls to drop-position after d&d.
  * Added: Drop on playlist allows insert (not just append).
  * Added: Manually controlled widths in library and playlist.
  * Added: Track titles shown across all colums in library.
  * Added: A first-run dialog with some useful tips.
  * Added: More details on command line in case of MPD-errors.
  * Lots of fixes and remakes.
- build changes
  * Mpd became required [#PM-66].
  * New program icon place.
  * Debuginfo was enabled.
* Sat May 19 2012 seife+obs@b1-systems.com
- fix build with gcc 4.7
* Wed Feb 23 2011 detlef@links2linux.de
- new upstream version <1.2.0>
  * Settings are now saved when applied (and on exit).
  * The volume slider is now always visible (was a pop-up).
  * The volume slider keeps the focus after a button click.
  * The progress bar is snappier (now based on QSlider).
  * "Modified" mode now sorts albums (rather than folders).
  * "Modified" now also possible when mpd runs remotely.
  * "Modified" now puts most recent item on top of the list.
  * "Modified" now handles missing tags correctly.
  * New library mode: Albums sorted by year (i.e. date tag).
  * Replaygain mode can now be set on the fly from Quimup.
  * Library and Playlist can be toggled to use full window.
  * Improved automatic column-width handling (i.m.h.o.).
  * "Reload audio tags" even when mod-time has not changed.
  * Fixed: 'Played' status was reset by "Reload audio tags".
  * Fixed: No response to 'disconnected' when in 'idle' mode.
  * "Collapse all" was added to the Library context menu.
  * Row colors now alternate in the library and playlist.
  * Tray icons were replaced (new and larger images).
  * Windows now always open normally (and never minimized).
  * Some minor cosmetic tweaks, as usual.
* Fri Jun 25 2010 detlef@links2linux.de
- new upstream version <1.1.1>
  * Volume slider now a pops up from the "status led".
  * Added volume control with mousewheel on "status led".
  * Playlist can now be rearranged (by drag & drop).
  * Added up/down keys to move through the playlist.
  * Added option to ignore leading 'the' when sorting artists.
  * "Start (mpd) with quimup" is now unchecked by default.
  * Added Ctrl-Q hotkey to close the player.
  * Fixed the "KDE logout was aborted by quimup" problem.
  * Year-tag format xxxx-xx-xx is now shown as xxxx only.
  * Empty year-tags are now ignored (prev. non-present only).
  * Fixed some typos.
  * Some cosmetic brush-ups, as usual.
* Sat May  8 2010 detlef@links2linux.de
- new upstream version <1.1.0>
* Sat Feb 21 2009 detlef@links2linux.de
- new upstream version <0.3.5>
  * Fixed: "KDE logout was cancelled by process quimup." (thanks Tilman Vogel)
  * Changed: Symlinks can now be used for album art (thanks Tilman Vogel)
  * Changed: Main MPD version is now shown as x.x (was the 'API' version x.x.x)
* Sat Jun 28 2008 detlef@links2linux.de
- new upstream version <0.3.4>
* Tue Feb 26 2008 detlef@links2linux.de
- new upstream version <0.3.3>
* Sat Jan 26 2008 detlef@links2linux.de
- new upstream version <0.3.2>
* Fri Nov 23 2007 detlef@links2linux.de
- new upstream version <0.3.1>
* Thu Oct 25 2007 detlef@links2linux.de
- initial build for packman
